summaryrefslogtreecommitdiffstats
path: root/umbrello/umbrello/clipboard/umlclipboard.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'umbrello/umbrello/clipboard/umlclipboard.cpp')
-rw-r--r--umbrello/umbrello/clipboard/umlclipboard.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/umbrello/umbrello/clipboard/umlclipboard.cpp b/umbrello/umbrello/clipboard/umlclipboard.cpp
index d654e083..069ba84b 100644
--- a/umbrello/umbrello/clipboard/umlclipboard.cpp
+++ b/umbrello/umbrello/clipboard/umlclipboard.cpp
@@ -267,7 +267,7 @@ void UMLClipboard::checkItemForCopyType(UMLListViewItem* Item, bool & WithDiagra
}
}
/** Adds the tqchildren of a UMLListViewItem to m_ItemList */
bool UMLClipboard::insertItemChildren(UMLListViewItem * Item, UMLListViewItemList& SelectedItems) {
if(Item->childCount()) {
UMLListViewItem * child = (UMLListViewItem*)Item->firstChild();
@@ -347,7 +347,7 @@ bool UMLClipboard::pasteClip1(TQMimeSource* data) {
return true;
lv->setStartedCopy(false);
/* If we get here we are pasting after a Copy and need to
// paste possible tqchildren.
UMLListViewItem* itemdata = 0;
UMLListViewItemListIt it(itemdatalist);
while ( (itemdata=it.current()) != 0 ) {
@@ -630,7 +630,7 @@ bool UMLClipboard::pasteClip5(TQMimeSource* data) {
break;
}
default :
- kWarning() << "pasting unknown tqchildren type in clip type 5" << endl;
+ kWarning() << "pasting unknown children type in clip type 5" << endl;
return false;
}
}
@@ -267,7 +267,7 @@ void UMLClipboard::checkItemForCopyType(UMLListViewItem* Item, bool & WithDiagra
}
}
-/** Adds the tqchildren of a UMLListViewItem to m_ItemList */
+/** Adds the children of a UMLListViewItem to m_ItemList */
bool UMLClipboard::insertItemChildren(UMLListViewItem * Item, UMLListViewItemList& SelectedItems) {
if(Item->childCount()) {
@@ -347,7 +347,7 @@ bool UMLClipboard::pasteClip1(TQMimeSource* data) {
lv->setStartedCopy(false);
/* If we get here we are pasting after a Copy and need to
- // paste possible tqchildren.
+ // paste possible children.
UMLListViewItem* itemdata = 0;
UMLListViewItemListIt it(itemdatalist);